@@ -1,24 +1,34 @@
 from .__about__ import __version__
+from ._cps import srfker96, surf96, swegn96
 from ._dispersion import DispersionCurve, GroupDispersion, PhaseDispersion
 from ._eigen import EigenFunction, LoveEigen, RayleighEigen
 from ._ellipticity import Ellipticity, RayleighEllipticity
-from ._sensitivity import GroupSensitivity, PhaseSensitivity, SensitivityKernel
-from ._surf96 import surf96
-from ._swegn96 import swegn96
+from ._exception import DispersionError
+from ._helpers import depthplot
+from ._sensitivity import (
+    EllipticitySensitivity,
+    GroupSensitivity,
+    PhaseSensitivity,
+    SensitivityKernel,
+)
 
 __all__ = [
+    "srfker96",
     "surf96",
     "swegn96",
+    "DispersionError",
     "DispersionCurve",
     "PhaseDispersion",
     "GroupDispersion",
     "SensitivityKernel",
     "PhaseSensitivity",
     "GroupSensitivity",
+    "EllipticitySensitivity",
     "LoveEigen",
     "RayleighEigen",
     "EigenFunction",
     "RayleighEllipticity",
     "Ellipticity",
+    "depthplot",
     "__version__",
 ]
